==> api-0.7.4-sources.jar: org/hansken/plugin/extraction/api/DeferredExtractionPlugin.java <==
package org.hansken.plugin.extraction.api;

import java.io.IOException;
import java.util.concurrent.ExecutionException;

import org.hansken.plugin.extraction.util.ThrowingConsumer;

/**
 * Deferred extraction plugins can be used by Hansken to process {@link Trace traces} during the extraction process.
 * A processed trace can be enriched with new information and new child traces can also be created.
 * <p>
 * The difference between this and a normal {@link ExtractionPlugin} is that this plugin is able to run a secondary query
 * for traces and combine the results with previously retrieved traces.
 * <p>
 * When a plugin matches on the trace which is currently processed by Hansken
 * (for example, because it has certain properties), the plugin will receive the
 * matched trace in order to process it (see {@link #process(Trace, DataContext, TraceSearcher)}).
 */
public interface DeferredExtractionPlugin extends BaseExtractionPlugin {

    /**
     * Start processing a {@link Trace trace}.
     * When processing a given trace, new properties may be set on it. New children can be added using
     * {@link Trace#newChild(String, ThrowingConsumer)}.
     * <p>
     * <strong>Note:</strong> the given trace should only be modified within the scope of this method.
     * Any modifications afterwards may be guarded against or result in undefined behaviour.
     *
     * @param trace the trace to process
     * @param dataContext data context of this trace extraction
     * @param searcher the searcher for the trace
     * @throws ExecutionException when an exception occurs while searching for traces
     * @throws InterruptedException when a thread gets interrupted while searching for traces
     * @throws IOException when an I/O exception occurs
     **/
    void process(Trace trace, DataContext dataContext, TraceSearcher searcher) throws ExecutionException, InterruptedException, IOException;
}

==> api-0.9.11-sources.jar: org/hansken/plugin/extraction/api/DeferredExtractionPlugin.java <==
package org.hansken.plugin.extraction.api;

import java.io.IOException;
import java.util.concurrent.ExecutionException;

import org.hansken.plugin.extraction.util.ThrowingConsumer;

/**
 * Deferred extraction plugins can be used by Hansken to process {@link Trace traces} during the extraction process.
 * A processed trace can be enriched with new information and new child traces can also be created.
 * <p>
 * The difference between this and a normal {@link ExtractionPlugin} is that this plugin is able to run a secondary query
 * for traces and combine the results with previously retrieved traces.
 * <p>
 * When a plugin matches on the trace which is currently processed by Hansken
 * (for example, because it has certain properties), the plugin will receive the
 * matched trace in order to process it (see {@link #process(Trace, DataContext, TraceSearcher)}).
 */
public interface DeferredExtractionPlugin extends BaseExtractionPlugin {

    /**
     * Start processing a {@link Trace trace}.
     * When processing a given trace, new properties may be set on it. New children can be added using
     * {@link Trace#newChild(String, ThrowingConsumer)}.
     * <p>
     * <strong>Note:</strong> the given trace should only be modified within the scope of this method.
     * Any modifications afterward may be guarded against or result in undefined behaviour.
     *
     * @param trace the trace to process
     * @param dataContext data context of this trace extraction
     * @param searcher the searcher for the trace
     * @throws ExecutionException when an exception occurs while searching for traces
     * @throws InterruptedException when a thread gets interrupted while searching for traces
     * @throws IOException when an I/O exception occurs
     **/
    void process(Trace trace, DataContext dataContext, TraceSearcher searcher) throws ExecutionException, InterruptedException, IOException;
}
